==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/nl.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Update notifications" : "Bijwerken meldingen",
    "Could not start updater, please try the manual update" : "Kon de updater niet starten, probeer alsjeblieft de handmatige update",
    "{version} is available. Get more information on how to update." : "{version} is beschikbaar. Meer informatie over het bijwerken.",
    "Channel updated" : "Kanaal bijgewerkt",
    "Update to %1$s is available." : "Update naar %1$s is beschikbaar.",
    "Update for %1$s to version %2$s is available." : "Update voor %1$s naar versie %2$s is beschikbaar.",
    "Update for {app} to version %s is available." : "Update voor {app} naar versie %s is beschikbaar.",
    "A new version is available: %s" : "Er is een nieuwe versie beschikbaar: %s",
    "Open updater" : "Open updater",
    "Download now" : "Download nu",
    "Your version is up to date." : "Je versie is up to date.",
    "Checked on %s" : "Gecontroleerd op %s",
    "Update channel:" : "Bijwerkkanaal:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Je kunt altijd updaten naar een nieuwere versie of experimenteel kanaal. Maar terug naar een oudere versie of een stabieler kanaal is niet mogelijk.",
    "Notify members of the following groups about available updates:" : "Geef een melding over beschikbare updates aan leden van de volgende groepen:",
    "Only notification for app updates are available." : "Er zijn alleen meldingen voor apps beschikbaar.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Het geselecteerde updatekanaal maakt overbodig om serverspecifieke meldingen apart te genereren.",
    "The selected update channel does not support updates of the server." : "Het geselecteerde updatekanaal ondersteunt geen updates voor de server.",
    "You are running PHP %s. To allow you to upgrade to Nextcloud 11 and higher you need to run at least PHP 5.6. Once you upgraded your PHP version you will be able to receive update notifications for these newer versions." : "Je draait PHP %s. Om te kunnen upgraden naar Nextcloud 11 of hoger, moet je minimaal PHP 5.6 draaien. Pas nadat je de PHP versie hebt bijgewerkt, zul je notificaties voor update naar de nieuwe versies ontvangen."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/nl.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Update notifications" : "Bijwerken meldingen",
    "Could not start updater, please try the manual update" : "Kon de updater niet starten, probeer alsjeblieft de handmatige update",
    "{version} is available. Get more information on how to update." : "{version} is beschikbaar. Meer informatie over het bijwerken.",
    "Channel updated" : "Kanaal bijgewerkt",
    "The update server could not be reached since %d days to check for new updates." : "De updateserver kon sinds %d dagen niet meer worden bereikt om op updates te controleren.",
    "Update to %1$s is available." : "Update naar %1$s is beschikbaar.",
    "Update for %1$s to version %2$s is available." : "Update voor %1$s naar versie %2$s is beschikbaar.",
    "Update for {app} to version %s is available." : "Update voor {app} naar versie %s is beschikbaar.",
    "A new version is available: %s" : "Er is een nieuwe versie beschikbaar: %s",
    "Open updater" : "Open updater",
    "Download now" : "Download nu",
    "Your version is up to date." : "Je versie is up to date.",
    "Checked on %s" : "Gecontroleerd op %s",
    "Update channel:" : "Bijwerkkanaal:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Je kunt altijd updaten naar een nieuwere versie of experimenteel kanaal. Maar terug naar een oudere versie of een stabieler kanaal is niet mogelijk.",
    "Notify members of the following groups about available updates:" : "Geef een melding over beschikbare updates aan leden van de volgende groepen:",
    "Only notification for app updates are available." : "Er zijn alleen meldingen voor apps beschikbaar.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Het geselecteerde updatekanaal maakt overbodig om serverspecifieke meldingen apart te genereren.",
    "The selected update channel does not support updates of the server." : "Het geselecteerde updatekanaal ondersteunt geen updates voor de server."
},
"nplurals=2; plural=(n != 1);");
